# Contributing

Contributions are very welcome.
Please file issues or submit pull requests in our [GitHub repository][repo].
All contributors will be acknowledged,
but must abide by our Code of Conduct.

## Setup

-   `uv venv` (once)
-   `source .venv/bin/activate`
-   `uv sync --dev`
-   `cd js && npm install`

[repo]: https://github.com/gvwilson/faw
